==> com.deepin.lianliankan_6.0.5.tar.xz: BUILD/translations/deepin-lianliankan_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>CloseWindowDialog</name>
    <message>
        <location filename="../src/source/closewindowdialog.cpp" line="34"/>
        <source>Are you sure you want to exit the game?</source>
        <translation>Er du sikker på, at du vil afslutte spillet?</translation>
    </message>
    <message>
        <location filename="../src/source/closewindowdialog.cpp" line="42"/>
        <source>Keep Playing</source>
        <translation>Fortsæt med at spille</translation>
    </message>
    <message>
        <location filename="../src/source/closewindowdialog.cpp" line="43"/>
        <source>Exit</source>
        <translation>Afslut</translation>
    </message>
</context>
<context>
    <name>GameoverBlurEffectWidget</name>
    <message>
        <location filename="../src/source/gameoverblureffectwidget.cpp" line="93"/>
        <source>Play Again</source>
        <translation>Spil igen</translation>
    </message>
    <message>
        <location filename="../src/source/gameoverblureffectwidget.cpp" line="94"/>
        <source>Have a Rest</source>
        <translation>Tag en pause</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../src/main.cpp" line="52"/>
        <source>LianLianKan</source>
        <translation>LianLianKan</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="53"/>
        <source>Lianliankan is a puzzle game.</source>
        <translation>Lianliankan er et puslespil.</translation>
    </message>
</context>
<context>
    <name>MainPage</name>
    <message>
        <location filename="../src/source/mainpage.cpp" line="32"/>
        <source>Easy</source>
        <translation>Let</translation>
    </message>
    <message>
        <location filename="../src/source/mainpage.cpp" line="33"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../src/source/mainpage.cpp" line="34"/>
        <source>Hard</source>
        <translation>Svært</translation>
    </message>
    <message>
        <location filename="../src/source/mainpage.cpp" line="52"/>
        <source>Select Level</source>
        <translation>Vælg niveau</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="97"/>
        <source>FAIL</source>
        <translation>FEJL</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="100"/>
        <source>VICTORY</source>
        <translation>SEJRE</translation>
    </message>
</context>
</TS>

==> com.deepin.lianliankan_6.0.11.tar.xz: BUILD/translations/deepin-lianliankan_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>CloseWindowDialog</name>
    <message>
        <location filename="../src/source/closewindowdialog.cpp" line="34"/>
        <source>Are you sure you want to exit the game?</source>
        <translation>Er du sikker på, at du vil afslutte spillet?</translation>
    </message>
    <message>
        <location filename="../src/source/closewindowdialog.cpp" line="42"/>
        <source>Keep Playing</source>
        <translation>Fortsæt med at spille</translation>
    </message>
    <message>
        <location filename="../src/source/closewindowdialog.cpp" line="43"/>
        <source>Exit</source>
        <translation>Afslut</translation>
    </message>
</context>
<context>
    <name>GameoverBlurEffectWidget</name>
    <message>
        <location filename="../src/source/gameoverblureffectwidget.cpp" line="93"/>
        <source>Play Again</source>
        <translation>Spil igen</translation>
    </message>
    <message>
        <location filename="../src/source/gameoverblureffectwidget.cpp" line="94"/>
        <source>Have a Rest</source>
        <translation>Tag en pause</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../src/main.cpp" line="52"/>
        <location filename="../src/main.cpp" line="54"/>
        <location filename="../src/main.cpp" line="55"/>
        <source>LianLianKan</source>
        <translation>LianLianKan</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="53"/>
        <source>Lianliankan is a puzzle game.</source>
        <translation>Lianliankan er et puslespil.</translation>
    </message>
</context>
<context>
    <name>MainPage</name>
    <message>
        <location filename="../src/source/mainpage.cpp" line="32"/>
        <source>Easy</source>
        <translation>Let</translation>
    </message>
    <message>
        <location filename="../src/source/mainpage.cpp" line="33"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../src/source/mainpage.cpp" line="34"/>
        <source>Hard</source>
        <translation>Svært</translation>
    </message>
    <message>
        <location filename="../src/source/mainpage.cpp" line="52"/>
        <source> Select Level </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="97"/>
        <source>FAIL</source>
        <translation>FEJL</translation>
    </message>
    <message>
        <location filename="../src/source/mainwindow.cpp" line="100"/>
        <source>VICTORY</source>
        <translation>SEJRE</translation>
    </message>
</context>
</TS>
